searchui/stateproviders/searchstateprovider/inc/searchprogressivestate.h
changeset 17 7d8c8d8f5eab
parent 12 993ab30e92fc
child 20 68cdadcf169e
--- a/searchui/stateproviders/searchstateprovider/inc/searchprogressivestate.h	Tue Jul 06 14:17:22 2010 +0300
+++ b/searchui/stateproviders/searchstateprovider/inc/searchprogressivestate.h	Wed Aug 18 09:49:49 2010 +0300
@@ -63,16 +63,16 @@
 #endif //OST_TRACE_COMPILER_IN_USE
 class HbMainWindow;
 class HbView;
-class HbDocumentLoader;
 class HbSearchPanel;
 class CFbsBitmap;
 class InDeviceHandler;
-class QCPixDocument;
+class CpixDocument;
 class NotesEditorInterface;
 class EventViewerPluginInterface;
 class HbListWidget;
 class HbListWidgetItem;
 class QPluginLoader;
+class SearchUiLoader;
 SEARCH_CLASS( SearchStateProviderTest)
 /** @ingroup group_searchstateprovider
  * @brief The state where progressive search state is shown
@@ -144,11 +144,20 @@
      */
     void constructHandlers();
 
+    InDeviceHandler* constructHandlers(int mDatabase);
+
     /**
      * setting the categories .
      * @since S60 ?S60_version.
      */
     void setSelectedCategories();
+
+    /**
+     * parse the result documents.
+     * @since S60 ?S60_version.
+     */
+    void parseDocument(CpixDocument* aDoc);
+
 public slots:
 
     /**
@@ -165,7 +174,16 @@
      * @param aError error code.
      * @param aDoc result item
      */
-    void onGetDocumentComplete(int aError, QCPixDocument* aDoc);
+    void onGetDocumentComplete(int aError, CpixDocument* aDoc);
+
+    /**
+     * slot connects to CSearchHandler to get the result item asynchronously 
+     * @since S60 ?S60_version.
+     * @param aError error code.
+     * @param aDoc result item
+     */
+    void onGetBatchDocumentComplete(int aError, int aCount,
+            CpixDocument** aDoc);
 
     /**
      * slot connects to list view to launch the respective application
@@ -205,7 +223,7 @@
     /**
      * slot connects to search state  for internet search
      * @since S60 ?S60_version.
-     */  
+     */
 
     void handleOk(const QVariant& var);
 
@@ -220,15 +238,37 @@
      * Slot implemented to delete the calenderviewer plugin  
      * @since S60 ?S60_version.
      */
-
     void _viewingCompleted();
 
+    /**
+     * Slot to notify when view is ready   
+     * @since S60 ?S60_version.
+     */
     void viewReady();
-    
+
+    /**
+     * Slot to notify form query update form online state   
+     * @since S60 ?S60_version.
+     */
     void slotOnlineQuery(QString);
-    
+
+    /**
+     * Slot to update the online service providers for suggestion links 
+     * @since S60 ?S60_version.
+     */
     void slotISProvidersIcon(int, HbIcon);
 
+    /**
+     * Slot to launch the search result screen with the activity URI  
+     * @since S60 ?S60_version.
+     */
+    void activityRequested(const QString &name);
+
+    /**
+     * Slot to notify when theme is changed
+     * @since S60 ?S60_version.
+     */
+    void slotPrepareResultIcons();
 private:
 
     /**
@@ -283,14 +323,14 @@
     void LaunchApplicationL(const TUid aUid);
 
     /**
      * Function to parse the  QCPixDocument with the given filter       
      */
-    QString filterDoc(const QCPixDocument* aDoc, const QString& filter);
+    QString filterDoc(const CpixDocument* aDoc, const QString& filter);
 
     /**
      * Function to parse the  QCPixDocument with the given filters       
      */
-    QStringList filterDoc(const QCPixDocument* aDoc, const QString& filter1,
+    QStringList filterDoc(const CpixDocument* aDoc, const QString& filter1,
             const QString& filter2, const QString& filter3 = QString());
 
     /**
@@ -312,10 +352,15 @@
      * setting state will be  activated.
      */
     void switchProToSettingsState();
-    
+
     void inDeviceSearchQuery(QString);
 
-    void launchLink(int,QString);
+    void launchLink(int, QString);
+
+    /**
+     * Signalled when UI is ready on progressive state        
+     */
+    void applicationReady();
 private:
 
     HbMainWindow* mMainWindow;
@@ -333,19 +378,11 @@
     HbListWidget* mListView;
 
     /**
-     * Document handler to load .docml.
-     * Own.
-     */
-    HbDocumentLoader* mDocumentLoader;
-
-    /**
      * The searchpanel widget.
      * Own.
      */
     HbSearchPanel* mSearchPanel;
 
- 
-
     /**
      * qt interface for CPix engine
      * Own.
@@ -444,9 +481,9 @@
      * 
      */
     QPluginLoader *mNotespluginLoader;
-    
+
     QMap<int, HbIcon> mISprovidersIcon;
-    
+
     bool mOnlineQueryAvailable;
 
 private:
@@ -467,6 +504,13 @@
      * 
      */
     QSize mListViewIconSize;
+
+    SearchUiLoader* mUiLoader;
+
+    bool mStateStatus;
+
+    bool mValidateHandlerCreation;
+
 #ifdef OST_TRACE_COMPILER_IN_USE
     QTime m_totalSearchUiTime;
     QTime m_categorySearchUiTime;
@@ -283,14 +323,14 @@
 
     /**
-     * Function to parse the  QCPixDocument with the given filter       
+     * Function to parse the  CpixDocument with the given filter       
      */
@@ -283,14 +323,14 @@
 
     /**
-     * Function to parse the  QCPixDocument with the given filters       
+     * Function to parse the  CpixDocument with the given filters       
      */